- Convert all CommonJS script to ES javascript modules
- Update HTML templates to load scripts as modules
- Update sidebar to use event listeners instead of inline JS
- Create a config.js file to hold configuration variables (e.g. backend URL)
